@@ -2,13 +2,19 @@ package Date::Holidays::ABSTRACTED;
 
 use base 'Date::Holidays::Abstract';
 
+sub new {
+    my $class = shift;
+    my $self = bless {}, $class;
+    return $self;
+}
+
 sub holidays {
-    return { 1224 => 'christmas' };    
+    return { 1224 => 'christmas' };
 }
 
 sub is_holiday {
-    my ($year, $month, $day) = @_;
-    
+    my ($class, $year, $month, $day) = @_;
+
     my $calendar = { 1224 => 'christmas' };
     my $key;
     if ($month && $day) {
